// Main.cpp - Lost on an Island
// 
// by Shane Costello and Andrew Claus
// Game Engine Code by Andre LaMothe

// INCLUDES ///////////////////////////////////////////////

#define WIN32_LEAN_AND_MEAN  

// you must #define INITGUID if not done elsewhere
#define INITGUID

#include <windows.h>   // include important windows stuff
#include <windowsx.h> 
#include <mmsystem.h>
#include <objbase.h>
#include <iostream> // include important C/C++ stuff
#include <conio.h>
#include <stdlib.h>
#include <malloc.h>
#include <memory.h>
#include <string.h>
#include <stdarg.h>
#include <stdio.h> 
#include <math.h>
#include <io.h>
#include <fcntl.h>
#include <ddraw.h>     // directX includes
#include "T3DLIB1.H"   // include the library header
#include <dsound.h> // include dsound, dmusic
#include <dmksctrl.h>
#include <dmusici.h>
#include <dmusicc.h>
#include <dmusicf.h>

#include "T3DLIB3.H"

// DEFINES ////////////////////////////////////////////////

// defines for windows 
#define WINDOW_CLASS_NAME "WINCLASS1"

RECT dest_rect;

// default screen size
#define SCREEN_WIDTH    640  // size of screen
#define SCREEN_HEIGHT   480
#define SCREEN_BPP      8    // bits per pixel

#define BITMAP_ID            0x4D42 // universal id for a bitmap
#define MAX_COLORS_PALETTE   256

// player directions
#define SKELATON_EAST         0
#define SKELATON_ESTILL       1  
#define SKELATON_BLANK		  2
#define SKELATON_WSTILL       3
#define SKELATON_WEST         4
#define SKELATON_JUMPUPE      5
#define SKELATON_JUMPDOWNE    6
#define SKELATON_JUMPUPW      7
#define SKELATON_JUMPDOWNW    8
#define SKELATON_ATTACKE	  9
#define SKELATON_ATTACKW	  10
#define SKELATON_SHOOTE	      11
#define SKELATON_SHOOTW		  12

#define BEAR_EAST     0
#define BEAR_WEST     1
#define BEAR_ATTACKE  2
#define BEAR_ATTACKW  3
#define BEAR_SPOTSE	  4
#define BEAR_SPOTSW   5

#define NUM_OF_BEARS  29
// bear awareness
#define UNAWARE		  0
#define SPOTS		  1
#define AWARE		  2
#define ATTACK		  3
#define OFFSCREEN	  4

#define BULLETE		  0
#define BULLETW		  1

#define START_GLOW_COLOR  186 // starting color index to glow
#define END_GLOW_COLOR    191 // ending color index to glow
#define FLOOR_COLOR		  240
#define ROCK_COLOR		  136

#define LOGO_TIME 6 // 6 # of seconds the logo is shown, 0 to skip
#define INTRO_TIME 30000000 // 15 # of seconds the intro is shown, 0 to skip

#define REGULAR_MUSIC   0
#define ATTACK_MUSIC    1
#define GAME_OVER		2
#define GAME_WIN		3

#define SNAKE_HURT		0
#define ALERT			1
#define HIT				2
#define SHOT			3
#define SNAKE_DEAD		5
#define ROAR			6
#define JUMP			7
#define KICK			8

struct Bullet
{
	int x;
	int y;
	bool live;
	int traveled;
	int direction;
};

// PROTOTYPES /////////////////////////////////////////////

// game console
int Logo_Init(void *parms=NULL, int num_parms = 0);
int Intro_Init(void *parms=NULL, int num_parms = 0);
int Game_Init(void *parms=NULL, int num_parms = 0);

int Logo_Shutdown(void *parms=NULL, int num_parms = 0);
int Intro_Shutdown(void *parms=NULL, int num_parms = 0);
int Game_Shutdown(void *parms=NULL, int num_parms = 0);

int Logo_Main(void *parms=NULL,  int num_parms = 0);
int Intro_Main(void *parms=NULL,  int num_parms = 0);
int Game_Main(void *parms=NULL,  int num_parms = 0);

void GameOver();
void GameWin();

// GLOBALS ////////////////////////////////////////////////

// windows vars
HWND      main_window_handle = NULL; // globally track main window
int       window_closed      = 0;    // tracks if window is closed
HINSTANCE main_instance      = NULL; // globally track hinstance

char buffer[80];                // used to print text

int midi_ids[10]; // hold storage for 10 songs ids
int sound_ids[9]; // storage for 4 sound fx ids

// game globals
BOB          skelaton;     // the player skelaton
BOB			 bear[NUM_OF_BEARS];  // the bear skelaton
BOB          fire;     // the camp fire
BOB			 hatch;    // the hatch
int			 timer = 0; // timer for length of logo screen
int			 introIndex=0; //control background picture change
int			 bullet_counter = 0;  // so bullets don't come out in bursts
int			 spot_counter = 0;  // keep track of number of times spotted

Bullet		 bullet[100]; // bullets

// animation sequences for bob
int skelaton_anims[13][4] = { {0,1,2,3},
                              {0+4,0+4,0+4,0+4},
                              {0+8,1+8,2+8,3+8},
                              {0+12,0+12,0+12,0+12},
                              {0+16,1+16,2+16,3+16},
                              {0+20,1+20,2+20,3+20},
                              {0+24,1+24,2+24,3+24},
                              {0+28,1+28,2+28,3+28},
							  {0+32,1+32,2+32,3+32},
							  {0+36,1+36,2+36,3+36},
                              {0+40,1+40,2+40,3+40},
                              {0+44,1+44,2+44,3+44},
							  {0+48,1+48,2+48,3+48}};

int bear_anims[6][4] =	   { {0,1,2,3},
                             {0+4,1+4,2+4,3+4},
                             {0+8,1+8,2+8,3+8},
                             {0+12,1+12,2+12,3+12},
							 {0+16,0+16,0+16,0+16},
                             {0+20,0+20,0+20,0+20}};

int fire_anims[4] = {0,1,0,1};
int hatch_anims[4] = {0,1,0,1};

BITMAP_IMAGE landscape[13];      // the background    landscape 13 page
BITMAP_IMAGE gameoverscreen;   // the game over screen
int curr_page = 0;              // current page of landscape

// PROTOTYPES //////////////////////////////////////////////

LRESULT CALLBACK WindowProc(HWND hwnd, 
						    UINT msg, 
                            WPARAM wparam, 
                            LPARAM lparam)
{
	// this is the main message handler of the system
	PAINTSTRUCT		ps;		// used in WM_PAINT
	HDC				hdc;	// handle to a device context
	char buffer[80];        // used to print strings

	// what is the message 
	switch(msg)
	{	
		case WM_CREATE: 
		{
			// do initialization stuff here
			// return success
			return(0);
		} break;
	
		case WM_PAINT: 
		{
			// simply validate the window 
   			hdc = BeginPaint(hwnd,&ps);	 
        
			// end painting
			EndPaint(hwnd,&ps);

	        // return success
			return(0);
   		} break;

		case WM_DESTROY: 
		{

			// kill the application, this sends a WM_QUIT message 
			PostQuitMessage(0);

			// return success
			return(0);
		} break;

		default:break;
	} // end switch

	// process any messages that we didn't take care of 
	return (DefWindowProc(hwnd, msg, wparam, lparam));

} // end WinProc

// WINMAIN ////////////////////////////////////////////////

int WINAPI WinMain(	HINSTANCE hinstance,
					HINSTANCE hprevinstance,
					LPSTR lpcmdline,
					int ncmdshow)
{

	WNDCLASSEX winclass; // this will hold the class we create
	HWND	   hwnd;	 // generic window handle
	MSG		   msg;		 // generic message
	HDC        hdc;      // graphics device context

	// first fill in the window class stucture
	winclass.cbSize         = sizeof(WNDCLASSEX);
	winclass.style			= CS_DBLCLKS | CS_OWNDC | 
                          CS_HREDRAW | CS_VREDRAW;
	winclass.lpfnWndProc	= WindowProc;
	winclass.cbClsExtra		= 0;
	winclass.cbWndExtra		= 0;
	winclass.hInstance		= hinstance;
	winclass.hIcon			= LoadIcon(NULL, IDI_APPLICATION);
	winclass.hCursor		= LoadCursor(NULL, IDC_ARROW); 
	winclass.hbrBackground	= (HBRUSH)GetStockObject(BLACK_BRUSH);
	winclass.lpszMenuName	= NULL;
	winclass.lpszClassName	= WINDOW_CLASS_NAME;
	winclass.hIconSm        = LoadIcon(NULL, IDI_APPLICATION);

	// save hinstance in global
	main_instance = hinstance;

	// register the window class
	if (!RegisterClassEx(&winclass))
		return(0);

	// create the window
	if (!(hwnd = CreateWindowEx(NULL,	// extended style
			WINDOW_CLASS_NAME,			// class
			"LOST on an Island",		// title
			WS_POPUP | WS_VISIBLE,
			0,0,						// initial x,y
			SCREEN_WIDTH,SCREEN_HEIGHT, // initial width, height
			NULL,						// handle to parent 
			NULL,						// handle to menu
			hinstance,					// instance of this application
			NULL)))						// extra creation parms
		return(0);
	
	// save main window handle
	main_window_handle = hwnd;

	// initialize logo here
	Logo_Init();
	// enter logo loop
	for(timer=0;timer<(LOGO_TIME*30);timer++)
	{
		// test if there is a message in queue, if so get it
		if (PeekMessage(&msg,NULL,0,0,PM_REMOVE))
		{ 
			// test if this is a quit
			if (msg.message == WM_QUIT)
				break;
			// translate any accelerator keys
			TranslateMessage(&msg);
			// send the message to the window proc
			DispatchMessage(&msg);
		} // end if
		// logo processing goes here
		Logo_Main();
	} // end while
	// closedown Logo here
	Logo_Shutdown();

	// initialize intro here
	Intro_Init();
	// enter intro loop


	for(timer=0;timer<(INTRO_TIME*30);timer++)
	{
		// test if there is a message in queue, if so get it
		if (PeekMessage(&msg,NULL,0,0,PM_REMOVE))
		{ 
			// test if this is a quit
			if (msg.message == WM_QUIT)
			{
				break;
			}
			// translate any accelerator keys
			TranslateMessage(&msg);
			// send the message to the window proc
			DispatchMessage(&msg);
		} // end if
		// intro processing goes here
		Intro_Main();
	} // end for
	// closedown intro here
	Intro_Shutdown();


	// initialize game here
	Game_Init();

	// enter main event loop
	while(TRUE)
	{
		// test if there is a message in queue, if so get it
		if (PeekMessage(&msg,NULL,0,0,PM_REMOVE))
		{ 
			// test if this is a quit
			if (msg.message == WM_QUIT)
				break;
	
			// translate any accelerator keys
			TranslateMessage(&msg);

			// send the message to the window proc
			DispatchMessage(&msg);
		} // end if
    
		// main game processing goes here
		Game_Main();
       
	} // end while

	// closedown game here
	Game_Shutdown();

	// return to Windows like this
	return(msg.wParam);

} // end WinMain

// GAME PROGRAMMING CONSOLE FUNCTIONS ////////////////

int Logo_Init(void *parms,  int num_parms)
{
	int index;         // looping var
	char filename[80]; // used to build up files names

	// initialize directsound
	DSound_Init();

	// initialize directmusic
	DMusic_Init();

	// load the midi segments
	midi_ids[0] = DMusic_Load_MIDI("intro.MID");

	

	// initialize directdraw
	DDraw_Init(SCREEN_WIDTH, SCREEN_HEIGHT, SCREEN_BPP);

	for (index = 0; index<1; index++)
    {
		// build up file name
		sprintf(filename,"LOGO.BMP");

		// load the background
		Load_Bitmap_File(&bitmap8bit, filename);

		// create and load the reactor bitmap image
		Create_Bitmap(&landscape[index], 0,0, 640, 480);
		Load_Image_Bitmap(&landscape[index],&bitmap8bit,0,0,BITMAP_EXTRACT_MODE_ABS);
		Unload_Bitmap_File(&bitmap8bit);
	}

	// set the palette to background image palette
	Set_Palette(bitmap8bit.palette);

	// set clipping rectangle to screen extents so mouse cursor
	// doens't mess up at edges
	RECT screen_rect = {0,0,screen_width,screen_height};
	lpddclipper = DDraw_Attach_Clipper(lpddsback,1,&screen_rect);


	//INITIALIZE ALL BOB's HERE!!!
	//
	// now let's load in all the frames for the skelaton!!!

	// create skelaton bob
	if (!Create_BOB(&skelaton,0,0,72,74,52, // 72x74  
           BOB_ATTR_VISIBLE | BOB_ATTR_MULTI_ANIM,DDSCAPS_SYSTEMMEMORY))
		return(0);

	//create fire bob
	if (!Create_BOB(&fire,0,0,72,74,4, // 72x74
           BOB_ATTR_VISIBLE | BOB_ATTR_MULTI_ANIM,DDSCAPS_SYSTEMMEMORY))
		return(0);

	//create hatch bob
     if (!Create_BOB(&hatch,0,0,72,74,4, // 72x74
           BOB_ATTR_VISIBLE | BOB_ATTR_MULTI_ANIM,DDSCAPS_SYSTEMMEMORY))
          return(0); 


	// load the frames in 8 directions, 4 frames each
	// each set of frames has a walk and a fire, frame sets
	// are loaded in counter clockwise order looking down
	// from a birds eys view or the x-z plane
	for (int direction = 0; direction < 13; direction++)
	{ 
		// build up file name
		sprintf(filename,"QUENSP%d.BMP",direction); // skelsp

		// load in new bitmap file
		Load_Bitmap_File(&bitmap8bit,filename);
 
		Load_Frame_BOB(&skelaton,&bitmap8bit,0+direction*4,0,0,BITMAP_EXTRACT_MODE_CELL);  
		Load_Frame_BOB(&skelaton,&bitmap8bit,1+direction*4,1,0,BITMAP_EXTRACT_MODE_CELL);  
		Load_Frame_BOB(&skelaton,&bitmap8bit,2+direction*4,2,0,BITMAP_EXTRACT_MODE_CELL);  
		Load_Frame_BOB(&skelaton,&bitmap8bit,3+direction*4,3,0,BITMAP_EXTRACT_MODE_CELL);

		// unload the bitmap file
		Unload_Bitmap_File(&bitmap8bit);

		// set the animation sequences for skelaton
		Load_Animation_BOB(&skelaton,direction,5,skelaton_anims[direction]);

    } // end for direction

	//build fire animations
	sprintf(filename,"FIRE1.BMP");
	Load_Bitmap_File(&bitmap8bit,filename);
	Load_Frame_BOB(&fire,&bitmap8bit,0,0,0,BITMAP_EXTRACT_MODE_CELL);
	Load_Frame_BOB(&fire,&bitmap8bit,1,1,0,BITMAP_EXTRACT_MODE_CELL);
	Unload_Bitmap_File(&bitmap8bit);
	Load_Animation_BOB(&fire,0,3,fire_anims);

	//build hatch animations
     sprintf(filename,"HATCH1.BMP");
     Load_Bitmap_File(&bitmap8bit,filename);
     Load_Frame_BOB(&hatch,&bitmap8bit,0,0,0,BITMAP_EXTRACT_MODE_CELL);
     Load_Frame_BOB(&hatch,&bitmap8bit,1,1,0,BITMAP_EXTRACT_MODE_CELL);
     Unload_Bitmap_File(&bitmap8bit);
     Load_Animation_BOB(&hatch,0,3,hatch_anims); 

	// set up starting state of fire
	Set_Animation_BOB(&fire, 0);
	Set_Anim_Speed_BOB(&fire, 3);
	Set_Vel_BOB(&fire, 0,0);
	Set_Pos_BOB(&fire, 70, 390); // right above the floor

	// set up starting state of skelaton
	Set_Animation_BOB(&skelaton, SKELATON_ESTILL);
	Set_Anim_Speed_BOB(&skelaton, 4);
	Set_Vel_BOB(&skelaton, 0,0);
	Set_Pos_BOB(&skelaton, 16, 335); // right above the floor

	// set up starting state of the hatch
     Set_Animation_BOB(&hatch, 0);
     Set_Anim_Speed_BOB(&hatch, 10);
     Set_Vel_BOB(&hatch, 0,0);
     Set_Pos_BOB(&hatch, 421, 407); 

	// create bear bob
	for(int i=0; i<NUM_OF_BEARS; i++)
	{
		if(!Create_BOB(&bear[i],0,0,72,74,24,
			BOB_ATTR_VISIBLE | BOB_ATTR_MULTI_ANIM,DDSCAPS_SYSTEMMEMORY))
		return (0);
	}

	// load the frames in 8 directions, 4 frames each
	// each set of frames has a walk and a fire, frame sets
	// are loaded in counter clockwise order looking down
	// from a birds eys view or the x-z plane
	for(int i = 0; i<NUM_OF_BEARS; i++)
	{
		for (int direction = 0; direction < 6; direction++)
		{ 
		// build up file name
		sprintf(filename,"BEAR%d.BMP",direction); // skelsp

		// load in new bitmap file
		Load_Bitmap_File(&bitmap8bit,filename);
 
		Load_Frame_BOB(&bear[i],&bitmap8bit,0+direction*4,0,0,BITMAP_EXTRACT_MODE_CELL);  
		Load_Frame_BOB(&bear[i],&bitmap8bit,1+direction*4,1,0,BITMAP_EXTRACT_MODE_CELL);  
		Load_Frame_BOB(&bear[i],&bitmap8bit,2+direction*4,2,0,BITMAP_EXTRACT_MODE_CELL);  
		Load_Frame_BOB(&bear[i],&bitmap8bit,3+direction*4,3,0,BITMAP_EXTRACT_MODE_CELL);


		// unload the bitmap file
		Unload_Bitmap_File(&bitmap8bit);

		// set the animation sequences for skelaton
		Load_Animation_BOB(&bear[i],direction,5,bear_anims[direction]);

		} // end for direction
	}

	for(int i = 0; i<NUM_OF_BEARS; i++)
	{
		// set up starting state of skelaton
		Set_Anim_Speed_BOB(&bear[i], 4);
		Set_Vel_BOB(&bear[i], 0,0);
		bear[i].max_count_1 = 0;
	}
	
	Set_Pos_BOB(&bear[0], (SCREEN_WIDTH * 1) + 400, 335); // screen 2 bears
	Set_Animation_BOB(&bear[0], BEAR_WEST);
	Set_Pos_BOB(&bear[1], (SCREEN_WIDTH * 1) + 100, 335);
	Set_Animation_BOB(&bear[1], BEAR_EAST);

	Set_Pos_BOB(&bear[2], (SCREEN_WIDTH * 2) + 100, 335); // screen 3 bears
	Set_Animation_BOB(&bear[2], BEAR_EAST);
	Set_Pos_BOB(&bear[3], (SCREEN_WIDTH * 2) + 300, 335);
	Set_Animation_BOB(&bear[3], BEAR_EAST);

	Set_Pos_BOB(&bear[4], (SCREEN_WIDTH * 3) + 300, 335); // screen 4 bears
	Set_Animation_BOB(&bear[4], BEAR_WEST);
	Set_Pos_BOB(&bear[5], (SCREEN_WIDTH * 3) + 550, 300);
	Set_Animation_BOB(&bear[5], BEAR_EAST);

	Set_Pos_BOB(&bear[6], (SCREEN_WIDTH * 4) + 200, 300); // screen 5 bears
	Set_Animation_BOB(&bear[6], BEAR_EAST);
	Set_Pos_BOB(&bear[7], (SCREEN_WIDTH * 4) + 300, 300);
	Set_Animation_BOB(&bear[7], BEAR_EAST);

	Set_Pos_BOB(&bear[8], (SCREEN_WIDTH * 5) + 200, 300); // screen 6 bears
	Set_Animation_BOB(&bear[8], BEAR_EAST);
	Set_Pos_BOB(&bear[9], (SCREEN_WIDTH * 5) + 300, 300);
	Set_Animation_BOB(&bear[9], BEAR_EAST);

	Set_Pos_BOB(&bear[10], (SCREEN_WIDTH * 6) + 200, 300); // screen 7 bears
	Set_Animation_BOB(&bear[10], BEAR_EAST);
	Set_Pos_BOB(&bear[11], (SCREEN_WIDTH * 6) + 300, 300);
	Set_Animation_BOB(&bear[11], BEAR_EAST);

	Set_Pos_BOB(&bear[12], (SCREEN_WIDTH * 7) + 200, 300); // screen 8 bears
	Set_Animation_BOB(&bear[12], BEAR_EAST);
	Set_Pos_BOB(&bear[13], (SCREEN_WIDTH * 7) + 300, 300);
	Set_Animation_BOB(&bear[13], BEAR_EAST);

	Set_Pos_BOB(&bear[14], (SCREEN_WIDTH * 8) + 200, 300); // screen 9 bears
	Set_Animation_BOB(&bear[14], BEAR_EAST);
	Set_Pos_BOB(&bear[15], (SCREEN_WIDTH * 8) + 300, 300);
	Set_Animation_BOB(&bear[15], BEAR_EAST);

	Set_Pos_BOB(&bear[16], (SCREEN_WIDTH * 9) + 200, 300); // screen 10 bears
	Set_Animation_BOB(&bear[16], BEAR_EAST);
	Set_Pos_BOB(&bear[17], (SCREEN_WIDTH * 9) + 300, 300);
	Set_Animation_BOB(&bear[17], BEAR_EAST);

	Set_Pos_BOB(&bear[18], (SCREEN_WIDTH * 10) + 200, 250); // screen 11 bears
	Set_Animation_BOB(&bear[18], BEAR_EAST);
	Set_Pos_BOB(&bear[19], (SCREEN_WIDTH * 10) + 400, 250);
	Set_Animation_BOB(&bear[19], BEAR_WEST);
	Set_Pos_BOB(&bear[20], (SCREEN_WIDTH * 10) + 500, 335);
	Set_Animation_BOB(&bear[20], BEAR_EAST);
	Set_Pos_BOB(&bear[26], (SCREEN_WIDTH * 10) + 200, 335);
	Set_Animation_BOB(&bear[26], BEAR_WEST);
	Set_Pos_BOB(&bear[27], (SCREEN_WIDTH * 10) + 300, 335);
	Set_Animation_BOB(&bear[27], BEAR_WEST);
	Set_Pos_BOB(&bear[28], (SCREEN_WIDTH * 10) + 400, 335);
	Set_Animation_BOB(&bear[28], BEAR_WEST);

	Set_Pos_BOB(&bear[21], (SCREEN_WIDTH * 11) + 100, 335); // screen 12 bears
	Set_Animation_BOB(&bear[21], BEAR_EAST);
	Set_Pos_BOB(&bear[22], (SCREEN_WIDTH * 11) + 500, 335);
	Set_Animation_BOB(&bear[22], BEAR_WEST);

	Set_Pos_BOB(&bear[23], (SCREEN_WIDTH * 12) + 100, 335); // screen 13 bears
	Set_Animation_BOB(&bear[23], BEAR_EAST);
	Set_Pos_BOB(&bear[24], (SCREEN_WIDTH * 12) + 200, 335);
	Set_Animation_BOB(&bear[24], BEAR_EAST);
	Set_Pos_BOB(&bear[25], (SCREEN_WIDTH * 12) + 300, 335);
	Set_Animation_BOB(&bear[25], BEAR_EAST);
	
	if(DMusic_Status_MIDI(midi_ids[0]) != MIDI_PLAYING)
		DMusic_Play(midi_ids[0]);

	// hide the mouse
	ShowCursor(FALSE);

	return(1);
}

int Intro_Init(void *parms,  int num_parms)
{
	int index;         // looping var
	char filename[80]; // used to build up files names
	timer = 0;		   // reset the timer, reuse for intro length

	// initialize directdraw
	DDraw_Init(SCREEN_WIDTH, SCREEN_HEIGHT, SCREEN_BPP);

	for (index = 0; index<5; index++)
    {
		// build up file name
		sprintf(filename,"CRASH%d.BMP",index+1);

		// load the background
		Load_Bitmap_File(&bitmap8bit, filename);

		// create and load the reactor bitmap image
		Create_Bitmap(&landscape[index], 0,0, 640, 480);
		Load_Image_Bitmap(&landscape[index],&bitmap8bit,0,0,BITMAP_EXTRACT_MODE_ABS);
		Unload_Bitmap_File(&bitmap8bit);
	}

	// set the palette to background image palette
	Set_Palette(bitmap8bit.palette);

	// set clipping rectangle to screen extents so mouse cursor
	// doens't mess up at edges
	RECT screen_rect = {0,0,screen_width,screen_height};
	lpddclipper = DDraw_Attach_Clipper(lpddsback,1,&screen_rect);

	// hide the mouse
	ShowCursor(FALSE);

	return(1);
}

int Game_Init(void *parms,  int num_parms)
{
	// this function is where you do all the initialization 
	// for your game

	int index;         // looping var
	char filename[80]; // used to build up files names

	// initialize directsound
	DSound_Init();

	// initialize directmusic
	DMusic_Init();
	
	// load in the digital sound
	sound_ids[SNAKE_HURT] = DSound_Load_WAV("SNAKE_DIE3.WAV");
	sound_ids[ALERT] = DSound_Load_WAV("alert.wav");
	sound_ids[HIT] = DSound_Load_WAV("punch.wav");
	sound_ids[SHOT] = DSound_Load_WAV("gunshot.wav");
	sound_ids[JUMP] = DSound_Load_WAV("jump.wav");
	sound_ids[SNAKE_DEAD] = DSound_Load_WAV("SNAKE_DIE1.WAV");
	sound_ids[KICK] = DSound_Load_WAV("jump.WAV");
	sound_ids[ROAR] = DSound_Load_WAV("bear.wav");


	// load the midi segments
	midi_ids[REGULAR_MUSIC] = DMusic_Load_MIDI("regular.MID");
	midi_ids[ATTACK_MUSIC] = DMusic_Load_MIDI("duel.MID");
	midi_ids[GAME_OVER] = DMusic_Load_MIDI("GameOver.MID");
	midi_ids[GAME_WIN] = DMusic_Load_MIDI("GameWin.MID");

	for(int i = 0; i<5; i++)
	{
		bullet[i].live = false;
		bullet[i].traveled = 0;
	}

	// initialize directdraw
	DDraw_Init(SCREEN_WIDTH, SCREEN_HEIGHT, SCREEN_BPP);

	// load in each page of the scrolling background
	for (index = 0; index<13; index++)
    {
		// build up file name
		sprintf(filename,"LANDSCAPE%d.BMP",index+1);

		// load the background
		Load_Bitmap_File(&bitmap8bit, filename);

		// create and load the reactor bitmap image
		Create_Bitmap(&landscape[index], 0,0, 640, 480);
		Load_Image_Bitmap(&landscape[index],&bitmap8bit,0,0,BITMAP_EXTRACT_MODE_ABS);
		Unload_Bitmap_File(&bitmap8bit);

    } // end for index

	// set the palette to background image palette
	Set_Palette(bitmap8bit.palette);
	//Save_Palette_To_File("yeayea.pal", bitmap8bit.palette);
/*
	Load_Bitmap_File(&bitmap8bit,"gameover.bmp");
	Create_Bitmap(&gameoverscreen,0,0,640,480);
	Load_Image_Bitmap(&gameoverscreen,&bitmap8bit,0,0,BITMAP_EXTRACT_MODE_ABS);
	Unload_Bitmap_File(&bitmap8bit);

	//Set_Palette(bitmap8bit.palette);
*/
	// set clipping rectangle to screen extents so mouse cursor
	// doens't mess up at edges
	RECT screen_rect = {0,0,screen_width,screen_height};
	lpddclipper = DDraw_Attach_Clipper(lpddsback,1,&screen_rect);

	// hide the mouse
	ShowCursor(FALSE);

	// return success
	return(1);

} // end Game_Init

///////////////////////////////////////////////////////////
int Logo_Shutdown(void *parms,  int num_parms)
{
	// kill the landscape
	for (int index=0; index<1; index++)
    Destroy_Bitmap(&landscape[index]);

	// shutdown directdraw
	//DDraw_Shutdown();

	return(1);
}
int Intro_Shutdown(void *parms,  int num_parms)
{
	

	// clear the drawing surface
	DDraw_Fill_Surface(lpddsback, 0);

	// lock the back buffer
	DDraw_Lock_Back_Surface();

	Draw_Bitmap(&landscape[4], back_buffer, back_lpitch, 0);

	// unlock the back buffer
	DDraw_Unlock_Back_Surface();

	// flip the surfaces
	DDraw_Flip();

	// delete all the music
	DMusic_Delete_All_MIDI();

	// shutdown directmusic
	DMusic_Shutdown();

	// kill the landscape
	for (int index=0; index<5; index++)
    Destroy_Bitmap(&landscape[index]);


	// shutdown directdraw
	//DDraw_Shutdown();

	return(1);
}
int Game_Shutdown(void *parms,  int num_parms)
{
	// this function is where you shutdown your game and
	// release all resources that you allocated

	// stop all sounds
	DSound_Stop_All_Sounds();

	// delete all sounds
	DSound_Delete_All_Sounds();

	// shutdown directsound
	DSound_Shutdown();

	// delete all the music
	DMusic_Delete_All_MIDI();

	// shutdown directmusic
	DMusic_Shutdown();

	// kill the landscape
	for (int index=0; index<13; index++)
		Destroy_Bitmap(&landscape[index]);

	Destroy_Bitmap(&gameoverscreen);

	// kill BOBs
	Destroy_BOB(&skelaton);
	Destroy_BOB(&fire);
	Destroy_BOB(&hatch); 
	for(int i = 0; i<NUM_OF_BEARS; i++)
	{
		Destroy_BOB(&bear[i]);
	}


	// shutdonw directdraw
	DDraw_Shutdown();

	// return success
	return(1);
} // end Game_Shutdown

///////////////////////////////////////////////////////////

int Logo_Main(void *parms, int num_parms)
{


	// check of user is trying to exit
	if (KEY_DOWN(VK_ESCAPE) || KEY_DOWN(VK_RETURN))
		PostMessage(main_window_handle, WM_DESTROY,0,0);

	// start the timing clock
	Start_Clock();

	// clear the drawing surface
	DDraw_Fill_Surface(lpddsback, 0);

	// lock the back buffer
	DDraw_Lock_Back_Surface();

	// draw the background reactor image
	Draw_Bitmap(&landscape[0], back_buffer, back_lpitch, 0);

	// unlock the back buffer
	DDraw_Unlock_Back_Surface();

	// flip the surfaces
	DDraw_Flip();

	// sync to 30 fps
	Wait_Clock(30);

	return(1);
}

int Intro_Main(void *parms, int num_parms)
{
	static bool show_title = false;
	static bool show_controls = false;

	static int  lastkey;
	

	if(DMusic_Status_MIDI(midi_ids[0]) != MIDI_PLAYING)
		DMusic_Play(midi_ids[0]);

	// check of user is trying to exit
	if (KEY_DOWN(VK_ESCAPE) || KEY_DOWN(VK_RETURN))
	{
		if(timer < 260) 
			timer = 260;
		else if(lastkey == 1)
			PostMessage(main_window_handle, WM_DESTROY,0,0);
	}

	// start the timing clock
	Start_Clock();

	// clear the drawing surface
	DDraw_Fill_Surface(lpddsback, 0);

	// lock the back buffer
	DDraw_Lock_Back_Surface();

	if(timer%15==0)
		introIndex++;

	// draw the background reactor image
	if(introIndex%2==0)
	{
		if(show_title==false)
			Draw_Bitmap(&landscape[0], back_buffer, back_lpitch, 0);
		else
			Draw_Bitmap(&landscape[2], back_buffer, back_lpitch, 0);
	}
	else
	{
		if(show_title==false)
			Draw_Bitmap(&landscape[1], back_buffer, back_lpitch, 0);
		else
			Draw_Bitmap(&landscape[3], back_buffer, back_lpitch, 0);
	}


	if(timer > 60 && show_controls == false)
	{
		Draw_Text_GDI("GRAY SNAKE, WORLD'S GREATEST SOLDIER, HAS CRASH LANDED",
		25,75, 255, lpddsback);
	}
	if(timer > 120 && show_controls == false)
	{
		Draw_Text_GDI("SOMEWHERE OVER THE MEDITERRANEAN SEA",
		25,95, 255, lpddsback);
	}
	if(timer > 200 && show_controls == false)
	{
		Draw_Text_GDI("HE MUST FIND A WAY OFF, OR FOREVER BE...",
		25,115, 255, lpddsback);
	}
	if(timer > 260)
	{
		if(show_controls == false)
			show_title = true;
		else if(show_controls == true)
			show_title = false;
		if(show_title == true)
			Draw_Text_GDI("PRESS ENTER TO PLAY OR CTRL FOR CONTROLS",
			25,440, 255, lpddsback);

		if(KEY_DOWN(VK_CONTROL))
		{
			show_controls = true;
		}

		if(show_controls == true)
		{
			Draw_Text_GDI("LEFT/RIGHT ARROWS - MOVEMENT",
			25,75, 255, lpddsback);
			Draw_Text_GDI("UP ARROW - JUMP",
			25,95, 255, lpddsback);
			Draw_Text_GDI("HOLD SPACE BAR - KICK",
			25,115, 255, lpddsback);
			Draw_Text_GDI("HOLD SHIFT - FIRE GUN",
			25,135, 255, lpddsback);
			Draw_Text_GDI("ENTER KEY - PAUSE",
			25,155, 255, lpddsback);
			Draw_Text_GDI("ESCAPE KEY - EXIT GAME (AND LOSE ALL PROGRESS)",
			25,175, 255, lpddsback);
			Draw_Text_GDI("ADVICE:",
			25,215, 1, lpddsback);
			Draw_Text_GDI("Gray Snake is the world's best soldier due his stealth skills",
			25,235, 1, lpddsback);
			Draw_Text_GDI("He can only kick an enemy while they are unaware of his presence",
			25,255, 1, lpddsback);
			Draw_Text_GDI("Avoid being seen, sneak up behind enemies and silently strike",
			25,275, 1, lpddsback);
			Draw_Text_GDI("Use your gun as a last resort, enemies will be able to hear it",
			25,295, 1, lpddsback);
			Draw_Text_GDI("Press SPACE BAR to return to main menu",
			25,440, 255, lpddsback);

			Draw_Text_GDI("Refer to the README file for full credits",
			350,400, 1, lpddsback);

			if(KEY_DOWN(VK_SPACE))
				show_controls = false;
		}
	}


	if(KEY_UP(VK_RETURN))
		lastkey = 1;
	else lastkey = 0;

	// unlock the back buffer
	DDraw_Unlock_Back_Surface();

	// flip the surfaces
	DDraw_Flip();

	// sync to 30 fps
	Wait_Clock(30);

	return(1);
}


int Game_Main(void *parms, int num_parms)
{
	
	// this is the workhorse of your game it will be called
	// continuously in real-time this is like main() in C
	// all the calls for you game go here!

	int          index;             // looping var
	int          dx=0,dy=0;         // general deltas used in collision detection
 
	static int   player_moving = 0; // tracks player motion
	static int   jump_peak = 0;     // tracks player jumping peak
	static int   base_jump_pos = 0; // saves player's initial jumping position
	static bool  touching_floor = true; // tracks whether player is touching the floor
	static bool  shooting = false;  // tracks whether player is shooting
	static int   kicking = 0;  // tracks whether player is kicking. 0 = not kicking, 1 = kicking left, 2 = kicking right
	static int   health = 100; // snake's health
	static int   ammo   = 100;  // snake's ammo
	static bool  paused = false; // pause state variable
	static bool  gameover = false; // game over state variable
	static bool  win = false; // win state variable

	static PALETTEENTRY glow = {0,0,0,PC_NOCOLLAPSE};  // used to animate blue water

	// check of user is trying to exit
	if (KEY_DOWN(VK_ESCAPE))
	    PostMessage(main_window_handle, WM_DESTROY,0,0);

	if(KEY_DOWN(VK_RETURN))
	{
		paused = true;
	}

	// start the timing clock
	Start_Clock();
	
	// clear the drawing surface
	DDraw_Fill_Surface(lpddsback, 0);

if(paused == false && gameover == false && win == false)
{
	// lock the back buffer
	DDraw_Lock_Back_Surface();

	// draw the background reactor image
	Draw_Bitmap(&landscape[curr_page], back_buffer, back_lpitch, 0);

	// unlock the back buffer
	DDraw_Unlock_Back_Surface();

	// reset motion flag
	player_moving = 0;
	
	if(curr_page == 12 && skelaton.x > 421 && skelaton.y > 470)
	{
		win = true;
		GameWin();
	}

	// sound and music mechanics *********************//
	int counter = 0;
	for(int i = 0; i < NUM_OF_BEARS; i++)
	{
		if(bear[i].state != 0)
		{
			if(bear[i].counter_1 == AWARE || bear[i].counter_1 == ATTACK)
			{
				counter += 1;
			}
			if(bear[i].counter_1 == SPOTS)
			{
				if(DSound_Status_Sound(sound_ids[ALERT]) != SOUND_PLAYING)
				{
					DSound_Play(sound_ids[ALERT]);
					Set_Sound_State(sound_ids[ALERT], SOUND_PLAYING);
				}
			} 
		}
	}
	
	if(counter == 0 && DMusic_Status_MIDI(midi_ids[REGULAR_MUSIC]) != MIDI_PLAYING)
	{
		DMusic_Play(midi_ids[REGULAR_MUSIC]);
	}
	else if(counter != 0 && DMusic_Status_MIDI(midi_ids[ATTACK_MUSIC]) != MIDI_PLAYING)
	{
		DMusic_Play(midi_ids[ATTACK_MUSIC]);
	}



	if(health > 0)
		Draw_Rectangle(8,8,health * 4,16, 29, lpddsback);
	else 
	{
		gameover = true;
		GameOver();
		
	}
	Draw_Text_GDI("HEALTH", 8, 24, 29, lpddsback);
	sprintf(buffer, "AMMO:  %d", ammo);
	Draw_Text_GDI(buffer, 75, 24, 29, lpddsback);


	// test direction of motion
	if (KEY_DOWN(VK_RIGHT) && shooting == false && kicking == 0) 
	{
		// move skelaton
		skelaton.x+=2;
		dx=2; dy=0;

		// set motion flag
		player_moving = 1;

		// check animation needs to change
		if (skelaton.curr_animation != SKELATON_EAST)
			Set_Animation_BOB(&skelaton,SKELATON_EAST);

	} // end if
	else if (KEY_DOWN(VK_LEFT) && shooting == false && kicking == 0)  
	{
		// move skelaton
		skelaton.x-=2;
		dx=-2; dy=0; 
   
		// set motion flag
		player_moving = 1;

		// check animation needs to change
		if (skelaton.curr_animation != SKELATON_WEST)
			Set_Animation_BOB(&skelaton,SKELATON_WEST);

	} // end if 
	// change animation to holding still 
	else if (player_moving == 0 && jump_peak == 0 && (skelaton.curr_animation == SKELATON_EAST || 
		     skelaton.curr_animation == SKELATON_JUMPDOWNE ||
		     skelaton.curr_animation == SKELATON_SHOOTE ||
		     skelaton.curr_animation == SKELATON_ATTACKE) && shooting == false && kicking == 0)
		Set_Animation_BOB(&skelaton,SKELATON_ESTILL);
	else if (player_moving == 0 && jump_peak == 0 && (skelaton.curr_animation == SKELATON_WEST || 
		     skelaton.curr_animation == SKELATON_JUMPDOWNW ||
		     skelaton.curr_animation == SKELATON_SHOOTW ||
		     skelaton.curr_animation == SKELATON_ATTACKW) && shooting == false && kicking == 0)
		Set_Animation_BOB(&skelaton,SKELATON_WSTILL);
	
	// change animation to jumping
	if(skelaton.yv <= 0 && jump_peak == 1 && (skelaton.curr_animation == SKELATON_ESTILL
	   || skelaton.curr_animation == SKELATON_EAST ||
	   skelaton.curr_animation == SKELATON_SHOOTE ||
	   skelaton.curr_animation == SKELATON_ATTACKE) && shooting == false && kicking == 0)
		Set_Animation_BOB(&skelaton,SKELATON_JUMPUPE);
	else if (skelaton.yv > 0 && jump_peak == 1 && skelaton.curr_animation == SKELATON_JUMPUPE)
		Set_Animation_BOB(&skelaton,SKELATON_JUMPDOWNE);
	else if (skelaton.yv <= 0 && jump_peak == 1 && (skelaton.curr_animation == SKELATON_WSTILL
		     || skelaton.curr_animation == SKELATON_WEST ||
		     skelaton.curr_animation == SKELATON_SHOOTW ||
		     skelaton.curr_animation == SKELATON_ATTACKW) && shooting == false && kicking == 0)
		Set_Animation_BOB(&skelaton,SKELATON_JUMPUPW);
	else if (skelaton.yv > 0 && jump_peak == 1 && skelaton.curr_animation == SKELATON_JUMPUPW)
		Set_Animation_BOB(&skelaton,SKELATON_JUMPDOWNW);
	else if (KEY_DOWN(VK_SHIFT) && !(KEY_DOWN(VK_UP)) && ammo > 0) // player is shooting
	{
		if(skelaton.curr_frame != 48 // end of animation cycle 
		   && (skelaton.curr_animation == SKELATON_ESTILL || // east-side shooting
		   skelaton.curr_animation == SKELATON_EAST ||
		   skelaton.curr_animation == SKELATON_SHOOTE)) 
		{
			shooting = true;
			if(skelaton.curr_animation != SKELATON_SHOOTE)
				Set_Animation_BOB(&skelaton, SKELATON_SHOOTE);
		}
		else if(skelaton.curr_frame != 52 // end of animation cycle 
			    && (skelaton.curr_animation == SKELATON_WSTILL || // west-side shooting
			    skelaton.curr_animation == SKELATON_WEST ||
			    skelaton.curr_animation == SKELATON_SHOOTW)) 
		{
			shooting = true;
			if(skelaton.curr_animation != SKELATON_SHOOTW)
				Set_Animation_BOB(&skelaton, SKELATON_SHOOTW);
		}
		else shooting = false;
	
		//	sprintf(buffer,"NOW!", skelaton.curr_frame);
		//	Draw_Text_GDI("NOW!",8,8,RGB(255,255,255),lpddsback); 
	
	} // end shooting if
	else if (KEY_DOWN(VK_SPACE)) // player is KICKING
	{
		if(DSound_Status_Sound(sound_ids[KICK]) != SOUND_PLAYING)
		{
			DSound_Play(sound_ids[KICK]);
			Set_Sound_State(sound_ids[KICK], SOUND_PLAYING);
		}

		if(skelaton.curr_frame == 38 || skelaton.curr_frame == 42)
		{
			if(DSound_Status_Sound(sound_ids[KICK]) == SOUND_PLAYING)
			{
				DSound_Stop_Sound(sound_ids[KICK]);
				Set_Sound_State(sound_ids[KICK], SOUND_STOPPED);
			}
		}

		if(skelaton.curr_frame != 40 // end of animation cycle 
		   && (skelaton.curr_animation == SKELATON_ESTILL || // east-side kicking
		   skelaton.curr_animation == SKELATON_EAST ||
		   skelaton.curr_animation == SKELATON_ATTACKE)) 
		{
			kicking = 2;
			if(skelaton.curr_animation != SKELATON_ATTACKE)
				Set_Animation_BOB(&skelaton, SKELATON_ATTACKE);
		}
		else if(skelaton.curr_frame != 44 // end of animation cycle 
			    && (skelaton.curr_animation == SKELATON_WSTILL || // west-side kicking
			    skelaton.curr_animation == SKELATON_WEST ||
			    skelaton.curr_animation == SKELATON_ATTACKW)) 
		{
			kicking = 1;
			if(skelaton.curr_animation != SKELATON_ATTACKW)
				Set_Animation_BOB(&skelaton, SKELATON_ATTACKW);
		}
		else kicking = 0;

		if (KEY_DOWN(VK_RIGHT))
		{
			// move skelaton
			skelaton.x+=2;
			dx=2; dy=0;

			// set motion flag
			player_moving = 1;

		} // end if
		else if (KEY_DOWN(VK_LEFT))  
		{
			// move skelaton
			skelaton.x-=2;
			dx=-2; dy=0; 
   
			// set motion flag
			player_moving = 1;
		}
	

	} // end kicking if

	if (KEY_DOWN(VK_UP) && shooting == false) // player is jumping
	{
		touching_floor = false;
		if(jump_peak == 0 && skelaton.yv == 0) // rising
		{
			if(DSound_Status_Sound(sound_ids[JUMP]) != SOUND_PLAYING)
			{
					DSound_Play(sound_ids[JUMP]);
			}
			skelaton.yv = -6.0; // give an upward velocity
			jump_peak = 1;
		}
		else if (jump_peak == 1) // falling
		{
			skelaton.yv += 0.45; // downward acceleration
		}
	}
	if (KEY_UP(VK_UP) && touching_floor == false) // player let go of up key, continue falling
	{
		skelaton.yv +=0.45;
	}

	if (KEY_UP(VK_SHIFT)) // player stops shooting
	{
		shooting = false;
	}

	if (KEY_UP(VK_SPACE)) // player stops kicking
	{
		kicking = 0;
	}

	if(jump_peak == 1) // if player is jumping
	{
		touching_floor = false;
		if(skelaton.y <= 380)
			skelaton.y += skelaton.yv; // change y position by y velocity
		else skelaton.y +=8 ; // otherwise keep player to floor
	}
	else // otherwise keep player to floor and don't allow them to jump mid-fall
	{
		skelaton.y += 8; 
		skelaton.yv = 0.1;
	}

	// *********************** bear mechanics ***************************** //
	for(int i = 0; i<NUM_OF_BEARS; i++)
	{
	  if(bear[i].state != 0)
	  {
		if((bear[i].x > SCREEN_WIDTH || (bear[i].x + bear[i].width) < 0) // bear is offscreen
			  && (bear[i].counter_1 == UNAWARE || bear[i].counter_1 == OFFSCREEN))// and not
		{																// chasing snake
			  bear[i].counter_1 = OFFSCREEN;
		}
		else if( ((bear[i].x + bear[i].width) < SCREEN_WIDTH && bear[i].x > 0) // bear is on 
			  && (bear[i].counter_1 == UNAWARE || bear[i].counter_1 == OFFSCREEN))// screen
		{
			bear[i].counter_1 = UNAWARE;
		}

		if(bear[i].counter_1 == UNAWARE) // bear does not see snake
		{
			if(bear[i].x <= SCREEN_WIDTH - (rand()%50) && 
				bear[i].curr_animation == BEAR_EAST) // bear continues to walk east
			{
				bear[i].x += 1;
				if (bear[i].curr_animation != BEAR_EAST)
					Set_Animation_BOB(&bear[i],BEAR_EAST);
				else if(bear[i].x >= SCREEN_WIDTH - (rand()%50))
					Set_Animation_BOB(&bear[i],BEAR_WEST); // bear turns around
			}
			else if(bear[i].x >= (rand()%200) && bear[i].curr_animation == BEAR_WEST)
			{ // bear continues to walk west
				bear[i].x -= 1;
				if (bear[i].curr_animation != BEAR_WEST)
					Set_Animation_BOB(&bear[i],BEAR_WEST);
				else if(bear[i].x <= (rand()%200)) // bear turns around
					Set_Animation_BOB(&bear[i],BEAR_EAST);
			}
		}
		else if(bear[i].counter_1 == SPOTS) // bear spots snake
		{
			if (bear[i].curr_animation == BEAR_EAST) // if bear is looking east
			{
				bear[i].counter_2 = 0;
				Set_Animation_BOB(&bear[i],BEAR_SPOTSE);// then animate to spots east
			}
			else if (bear[i].curr_animation == BEAR_WEST) // same but west
			{
				bear[i].counter_2 = 0;
				Set_Animation_BOB(&bear[i],BEAR_SPOTSW);
			}
			else if(bear[i].counter_2 >= 60) 
			{
				bear[i].counter_1 = AWARE; // aware after 60 frames

				if(skelaton.x < bear[i].x) // snake is left, bear moves left
				{
					if(bear[i].curr_animation != BEAR_WEST)
						Set_Animation_BOB(&bear[i],BEAR_WEST);
				}
				else if(skelaton.x >= bear[i].x) // snake is right, bear moves right
				{
					if(bear[i].curr_animation != BEAR_EAST)
						Set_Animation_BOB(&bear[i],BEAR_EAST);
				}

			}
			else bear[i].counter_2 += 1; // increment counter
			
		}
		else if(bear[i].counter_1 == AWARE) // bear knows where snake is and is pursuing
		{
			if(DSound_Status_Sound(sound_ids[ALERT]) == SOUND_PLAYING)
			{
				Set_Sound_State(sound_ids[ALERT], SOUND_STOPPED);
			}
			bear[i].counter_2 = 0;
			if(skelaton.x < bear[i].x) // snake is left, bear moves left
			{
				bear[i].x -= 2;
				if(bear[i].curr_animation != BEAR_WEST)
					Set_Animation_BOB(&bear[i],BEAR_WEST);
			}
			else if(skelaton.x > bear[i].x) // snake is right, bear moves right
			{
				bear[i].x += 2;
				if(bear[i].curr_animation != BEAR_EAST)
					Set_Animation_BOB(&bear[i],BEAR_EAST);
			}
			/*
			else 
			{
				bear[i].x -= 2;
				if(bear[i].curr_animation != BEAR_WEST)
					Set_Animation_BOB(&bear[i],BEAR_WEST);
			} */
		}
		else if(bear[i].counter_1 == ATTACK) // bear is within range of attack
		{
			if (bear[i].curr_animation == BEAR_EAST) // if bear is looking east
			{
				Set_Animation_BOB(&bear[i],BEAR_ATTACKE);// then animate to attack east
			}
			else if (bear[i].curr_animation == BEAR_WEST) // same but west
			{
				Set_Animation_BOB(&bear[i],BEAR_ATTACKW);
			}

			if(bear[i].curr_frame == 11)
			{
				skelaton.x += 20;
				health -= 10;
				if(DSound_Status_Sound(sound_ids[HIT]) != SOUND_PLAYING)
						DSound_Play(sound_ids[HIT]);
				if(DSound_Status_Sound(sound_ids[SNAKE_HURT]) != SOUND_PLAYING)
						DSound_Play(sound_ids[SNAKE_HURT], 0, 100, 0,0);
				//Draw_Text_GDI("Snake gets damaged",8,8,RGB(255,255,255),lpddsback);
			}
			if(bear[i].curr_frame == 15)
			{
				health -= 10;
				skelaton.x -= 20;
				if(DSound_Status_Sound(sound_ids[HIT]) != SOUND_PLAYING)
						DSound_Play(sound_ids[HIT]);
				if(DSound_Status_Sound(sound_ids[SNAKE_HURT]) != SOUND_PLAYING)
						DSound_Play(sound_ids[SNAKE_HURT]);
				//Draw_Text_GDI("Snake gets damaged",8,8,RGB(255,255,255),lpddsback);
			}

			if(skelaton.x < bear[i].x) // snake is left, bear moves left
			{
				bear[i].x -= 2;
			}
			else if(skelaton.x > bear[i].x) // snake is right, bear moves right
			{
				bear[i].x += 2;
			}
		}

		if(bear[i].counter_1 != OFFSCREEN)
			bear[i].y +=2; // bear gravity

	  } // end if
	} // end for

	if((skelaton.curr_frame == 46 || skelaton.curr_frame == 50)
		&& bullet_counter == 0) // create a new bullet
	{
		if(skelaton.curr_frame == 46)
		{
			int i = 0;
			while(bullet[i].live == true)
				i++;

			bullet[i].live = true;
			bullet[i].direction = 1;
			bullet[i].traveled = 0;
			bullet[i].x = skelaton.x;
			bullet[i].y = skelaton.y + 37;
		}
		else if(skelaton.curr_frame == 50)
		{
			int i = 0;
			while(bullet[i].live == true)
				i++;

			bullet[i].live = true;
			bullet[i].direction = 0;
			bullet[i].traveled = 0;
			bullet[i].x = skelaton.x;
			bullet[i].y = skelaton.y + 37;
		}

		if(DSound_Status_Sound(sound_ids[SHOT]) != SOUND_PLAYING)
			DSound_Play(sound_ids[SHOT]);

		ammo -= 1;

		for(int i = 0; i<NUM_OF_BEARS; i++)
		{
			if(bear[i].state != 0)
			{
				if(abs(bear[i].x - skelaton.x) <= SCREEN_WIDTH)
				{
					if(bear[i].counter_1 == UNAWARE)
						bear[i].counter_1 = SPOTS;
				}
			}
		}

		bullet_counter = 1;
	}
	
	if(bullet_counter != 0)  bullet_counter += 1;
	if(bullet_counter == 10) bullet_counter = 0;
	// *********************** bullet mechanics ***************************** //

	for(int i = 0; i < 100; i++)
	{
		for(int j = 0; j < NUM_OF_BEARS; j++)
		{
			if(bear[j].state != 0)
			{
				if( bullet[i].live == true &&
					bullet[i].x > bear[j].x && bullet[i].x < (bear[j].x + bear[j].width) &&
					bullet[i].y > bear[j].y + 25 && bullet[i].y < bear[j].y + bear[j].height)
				{
					//Draw_Text_GDI("BEAR IS HIT!",8,55,255,lpddsback);
					if(bullet[i].direction == 0)
						bear[j].x -= 20;
					else if(bullet[i].direction == 1)
						bear[j].x += 20;
					bullet[i].live = false;

					if(DSound_Status_Sound(sound_ids[HIT]) != SOUND_PLAYING)
						DSound_Play(sound_ids[HIT]);
					
					bear[j].max_count_1 += 1;
					if(bear[j].max_count_1 >= 3) // if bear has 3 hits
					{
						Destroy_BOB(&bear[j]); // bear is dead
						//if(DSound_Status_Sound(sound_ids[ROAR]) != SOUND_PLAYING)
							DSound_Play(sound_ids[ROAR]);
					}

					break;
				}
			}
		}
		if(bullet[i]. live == true && bullet[i].traveled < 600)
		{
			if(bullet[i].direction == 0)
			{
				bullet[i].x -= 10;
				bullet[i].traveled += 10;
			}
			else if(bullet[i].direction == 1)
			{
				bullet[i].x += 10;
				bullet[i].traveled += 10;
			}
		}
		else bullet[i].live = false;
	}
	

	// animate skelaton
	Animate_BOB(&skelaton);
	Animate_BOB(&fire);
	Animate_BOB(&hatch); 
	for(int i = 0; i<NUM_OF_BEARS; i++)
		if(bear[i].state != 0)
			Animate_BOB(&bear[i]);

	// lock surface, so we can scan it
	DDraw_Lock_Back_Surface();
   
	// call the color scanner with FLOOR_COLOR, the color of the glowing floor
	// try to center the scan on the feet of the player, make sure feet stay
	// in contact with floor
	if(skelaton.x > -25)
	while(Color_Scan(skelaton.x+25, skelaton.y+60,
		  skelaton.x+skelaton.width-26, skelaton.y+skelaton.height-6,                                    
          FLOOR_COLOR, FLOOR_COLOR, back_buffer,back_lpitch)
		  ||Color_Scan(skelaton.x+28, skelaton.y+60,
		  skelaton.x+skelaton.width-29, skelaton.y+skelaton.height-6,                                    
          ROCK_COLOR, ROCK_COLOR, back_buffer,back_lpitch))
	{
		// push the skelaton upward, to keep it on the floor
		skelaton.y-=1;
		base_jump_pos = skelaton.y; // saves the player's initial jumping position
		jump_peak = 0; // player is now allowed to jump again now that they have reached the floor
		touching_floor = true; // player is currently touching the floor
		skelaton.yv = 0; // player has a zero y velocity
	} // end while

	else while(Color_Scan(1, skelaton.y+60, // different version for if snake is on left side
		  skelaton.x+skelaton.width-26, skelaton.y+skelaton.height-6, // otherwise for some                                   
          FLOOR_COLOR, FLOOR_COLOR, back_buffer,back_lpitch)
		  ||Color_Scan(1, skelaton.y+60, // different version for if snake is on left side
		  skelaton.x+skelaton.width-26, skelaton.y+skelaton.height-6, // otherwise for some                                   
          ROCK_COLOR, ROCK_COLOR, back_buffer,back_lpitch)) // reason he falls thru floor
	{
		// push the skelaton upward, to keep it on the floor
		skelaton.y-=1;
		base_jump_pos = skelaton.y; // saves the player's initial jumping position
		jump_peak = 0; // player is now allowed to jump again now that they have reached the floor
		touching_floor = true; // player is currently touching the floor
		skelaton.yv = 0; // player has a zero y velocity
	}

	//Snake left wall detection
	while(Color_Scan(skelaton.x+26,skelaton.y+25,skelaton.x+skelaton.width-36,
		  skelaton.y+skelaton.height-12,                                    
          ROCK_COLOR, ROCK_COLOR, back_buffer,back_lpitch))
	{
		// push the skelaton right
		skelaton.x+=1;
	}

	//Snake right wall detection
	while(Color_Scan(skelaton.x+skelaton.width-36,skelaton.y+25,skelaton.x+skelaton.width-27, 
		  skelaton.y+skelaton.height-12,                                   
          ROCK_COLOR, ROCK_COLOR, back_buffer,back_lpitch))
	{
		// push the skelaton right
		skelaton.x-=1;
	}

	for (int i=0; i<NUM_OF_BEARS; i++)
	{
		if(bear[i].state != 0)
		{
			if(bear[i].x > 0)
			while(Color_Scan(bear[i].x+20, bear[i].y+60,
				bear[i].x+bear[i].width-19, bear[i].y+bear[i].height-6,                                    
				FLOOR_COLOR, FLOOR_COLOR, back_buffer,back_lpitch)
				||Color_Scan(bear[i].x+20, bear[i].y+60,
				bear[i].x+bear[i].width-19, bear[i].y+bear[i].height-6,                                    
				ROCK_COLOR, ROCK_COLOR, back_buffer,back_lpitch))
			{
				// push the bear upward, to keep it on the floor
				bear[i].y-=1;
			} // end while
			else while(Color_Scan(1, bear[i].y+60,
				bear[i].x+bear[i].width, bear[i].y+bear[i].height-6,                                    
				FLOOR_COLOR, FLOOR_COLOR, back_buffer,back_lpitch)
				||Color_Scan(1, bear[i].y+60,
				bear[i].x+bear[i].width, bear[i].y+bear[i].height-6,                                    
				ROCK_COLOR, ROCK_COLOR, back_buffer,back_lpitch))
			{
				// push the bear upward, to keep it on the floor
				bear[i].y-=1;
			} // end while

			if(bear[i].counter_1 != ATTACK)
            {
				if(Color_Scan(bear[i].x+5, bear[i].y+29, 
                bear[i].x+bear[i].width-40, bear[i].y+bear[i].height-12,                                    
                ROCK_COLOR, ROCK_COLOR, back_buffer,back_lpitch)) 
                { 
					if(bear[i].curr_animation == BEAR_WEST) 
                          Set_Animation_BOB(&bear[i],BEAR_EAST); 
                } 
                if(Color_Scan(bear[i].x+40, bear[i].y+29, 
                       bear[i].x+bear[i].width-5, bear[i].y+bear[i].height-12,                                    
						ROCK_COLOR, ROCK_COLOR, back_buffer,back_lpitch)) 
                { 
					if(bear[i].curr_animation == BEAR_EAST) 
                           Set_Animation_BOB(&bear[i],BEAR_WEST); 
                }
			} 
		}
	}
	// done, so unlock
	DDraw_Unlock_Back_Surface();

	// draw the BOBs 
	for(int i=0; i<NUM_OF_BEARS; i++) 
		if(bear[i].state != 0)
			Draw_BOB(&bear[i], lpddsback); 

	DDraw_Lock_Back_Surface(); 
	// call the color scanner with a BEAR color, the color of the wall 
	// try to center the scan on the left of the player, make sure user 
	// cannot move through objects
	
	if(kicking==1) //if snake is kicking left, large colorscan, damage the bear
	{
		int kick_pos = Color_Scan(skelaton.x+14,skelaton.y+25,skelaton.x+skelaton.width-36,
			  skelaton.y+skelaton.height-12,                                     
			  255, 255, back_buffer,back_lpitch);
		if(kick_pos) // within range of bear
		{ 
			if(skelaton.curr_frame == 43) // kick is making contact
			{
				int closest = 600;
				int closest_bear;
				for(int i = 0; i<NUM_OF_BEARS; i++) // find closest bear
				{
					if(bear[i].state != 0)
					if( abs( kick_pos - (bear[i].x + bear[i].width)) < closest)
					{
						closest = abs(kick_pos - (bear[i].x + (bear[i].width)));
						closest_bear = i;
					}
					
				}
				if(bear[closest_bear].counter_1 == UNAWARE)
				{
					if(DSound_Status_Sound(sound_ids[HIT]) != SOUND_PLAYING)
							DSound_Play(sound_ids[HIT]);
					bear[closest_bear].x -= 20; // bear gets pushed back
					bear[closest_bear].max_count_1 += 3; // increment # of hits on bear
					if(bear[closest_bear].max_count_1 >= 3) // if bear has 3 hits
					{
						Destroy_BOB(&bear[closest_bear]); // bear is dead
								DSound_Play(sound_ids[ROAR]);
					}
				}
			}
		}
	}


	// call the color scanner with a BEAR color, the color of the wall 
	// try to center the scan on the right of the player, make sure user 
	// cannot move through objects
	if(kicking==2) //if snake is kicking right, large colorscan, damage the bear
	{
		int kick_pos = Color_Scan(skelaton.x+skelaton.width-36,skelaton.y+25,skelaton.x+skelaton.width-14, 
			  skelaton.y+skelaton.height-12,                                     
              255, 255, back_buffer,back_lpitch);
		if(kick_pos) // within range of the bear
		{ 
			if(skelaton.curr_frame == 39) // the kick is making contact
			{
				int closest = 600;
				int closest_bear;
				for(int i = 0; i<NUM_OF_BEARS; i++) // find the bear snake is kicking
				{
					if(bear[i].state != 0)
					if( abs( (kick_pos - bear[i].x)) < closest)
					{
						closest = abs(kick_pos - bear[i].x);
						closest_bear = i;
					}
					 
				}
				if(bear[closest_bear].counter_1 == UNAWARE)
				{
					if(DSound_Status_Sound(sound_ids[HIT]) != SOUND_PLAYING)
							DSound_Play(sound_ids[HIT]);
					bear[closest_bear].x += 20; // bear gets pushed back
					bear[closest_bear].max_count_1 += 3; // increment # of hits on bear
					if(bear[closest_bear].max_count_1 >= 3) // if bear has 3 hits
					{
						Destroy_BOB(&bear[closest_bear]); // bear is dead
								DSound_Play(sound_ids[ROAR]);
					}
				}
			}
		}
	}



	
	DDraw_Unlock_Back_Surface(); 


	Draw_BOB(&skelaton, lpddsback);
	if(curr_page==0||curr_page==2||curr_page==4||curr_page==7||curr_page==11)
          Draw_BOB(&fire, lpddsback);

	if(curr_page==12) 
		Draw_BOB(&hatch, lpddsback); 



	for(int i = 0; i<100; i++)
	{
		if(bullet[i].live == true && bullet[i].direction == 0)
			Draw_Rectangle(bullet[i].x + 15, bullet[i].y, bullet[i].x + 18, 
				bullet[i].y + 2, 255, lpddsback);
		else if(bullet[i].live == true && bullet[i].direction == 1)
			Draw_Rectangle(bullet[i].x + skelaton.width - 15, bullet[i].y, 
			bullet[i].x + skelaton.width - 12, bullet[i].y + 2, 255, lpddsback);
	}

	DDraw_Lock_Back_Surface(); // so we can scan

	for (int i = 0; i<NUM_OF_BEARS; i++)
	{
		if(bear[i].state != 0)
		{
			if(bear[i].curr_animation == BEAR_WEST && bear[i].counter_1 == UNAWARE) // bear's left vision range
				if(Color_Scan(bear[i].x-100, bear[i].y + 25,bear[i].x + 20, 
					bear[i].y+bear[i].height-25,61,61, back_buffer, back_lpitch))
				{
					bear[i].counter_1 = SPOTS;
				}
			if(bear[i].curr_animation == BEAR_EAST && bear[i].counter_1 == UNAWARE) // bear's right vision range
				if(Color_Scan(bear[i].x + bear[i].width - 20, bear[i].y,
					bear[i].x + bear[i].width + 100, bear[i].y+bear[i].height-25,
					61,61, back_buffer, back_lpitch))
				{
					bear[i].counter_1 = SPOTS;
				}
			if(bear[i].counter_1 == AWARE || bear[i].counter_1 == ATTACK)
			{
				if(Color_Scan(bear[i].x, bear[i].y+25,bear[i].x+bear[i].width, 
					bear[i].y+bear[i].height, 61, 61, back_buffer, back_lpitch))
				{
					bear[i].counter_1 = ATTACK;
				
				}
				else bear[i].counter_1 = AWARE;
			}
		}
	} // end for
	
	DDraw_Unlock_Back_Surface();
	
	////////////////DEBUGGING SQUARES - DO NOT DELETE//////////////////////////
	// Copy and paste the appropriate coordinates to the color scan
	//Snake left kick
//	Draw_Rectangle(skelaton.x+14,skelaton.y+25,skelaton.x+skelaton.width-36,
//		           skelaton.y+skelaton.height-12,50, lpddsback);	
	//Snake right kick
//	Draw_Rectangle(skelaton.x+skelaton.width-36,skelaton.y+25,skelaton.x+skelaton.width-14, 
//		           skelaton.y+skelaton.height-12, 129, lpddsback);
	//Snake floor
//	Draw_Rectangle(skelaton.x+25, skelaton.y+60,
//		           skelaton.x+skelaton.width-26, skelaton.y+skelaton.height-6,202, lpddsback); 
	//Snake left hit
//	Draw_Rectangle(skelaton.x+30,skelaton.y+25,skelaton.x+skelaton.width-36,
//				   skelaton.y+skelaton.height-12,240, lpddsback);
	//Snake right hit
//	Draw_Rectangle(skelaton.x+skelaton.width-36,skelaton.y+25,skelaton.x+skelaton.width-30, 
//				   skelaton.y+skelaton.height-12,5, lpddsback);
	//Snake bullet																- not being used in a color scan at the moment
//	Draw_Rectangle(skelaton.x+25,skelaton.y+25,skelaton.x+skelaton.width-26,
//				   skelaton.y+skelaton.height-12,244, lpddsback);
	//PolarBear Floor
//	Draw_Rectangle(bear[0].x+20, bear[0].y+60,
//              bear[0].x+bear[0].width-19, bear[0].y+bear[0].height-6,222, lpddsback);
	//PolarBear bullet															- not being used in a color scan at the moment
//	Draw_Rectangle(bear[0].x+5, bear[0].y+29,
//				   bear[0].x+bear[0].width-5, bear[0].y+bear[0].height-12,242, lpddsback);
	//PolarBear swipe															- not being used in a color scan at the moment
//	Draw_Rectangle(bear[0].x-10, bear[0].y+20,
//		           bear[0].x+bear[0].width+10, bear[0].y+bear[0].height,102, lpddsback);
	//PolarBear follow															- not being used in a color scan at the moment
//	if(bear[0].curr_animation == BEAR_WEST)
//		Draw_Rectangle(bear[0].x-200, bear[0].y,
//				   bear[0].x + 20, bear[0].y+bear[0].height+25,202, lpddsback);
//	if(bear[0].curr_animation == BEAR_EAST)
//		Draw_Rectangle(bear[0].x + bear[0].width - 20, bear[0].y,
//			bear[0].x + bear[0].width + 200, bear[0].y+bear[0].height+25,202, lpddsback);
	////////////////////////END DEBUGGING SQUARES//////////////////////////////////

	/* 
	// this performs the animation for the glowing rock
	static int glow_count = 0;

	// increment action counter and test
	if (++glow_count > 5)
	{
		// rotate the colors
		Rotate_Colors(START_GLOW_COLOR,END_GLOW_COLOR);
		// reset the counter
		glow_count = 0;
	} // end if
	*/

	// animate the floor
	//glow.peGreen = rand()%256;
	//Set_Palette_Entry(FLOOR_COLOR, &glow);

	// test for page flip right
	if (skelaton.x > SCREEN_WIDTH - (skelaton.width >> 1))
	{
	// bump back regardless
		skelaton.x-=dx;

		// test for page flip
		if (curr_page < 12)
		{ 
			// scroll to next page to right
			curr_page++;
			//reset fire to new position
               if(curr_page==0)
                    Set_Pos_BOB(&fire, 70, 390);
               else if(curr_page==2)
                    Set_Pos_BOB(&fire, 250, 380);
               else if(curr_page==4)
                    Set_Pos_BOB(&fire, 175, 390);
               else if(curr_page==7)
                    Set_Pos_BOB(&fire, 375, 390);
               else if(curr_page==11)
                    Set_Pos_BOB(&fire, 330, 410); 

			// reset character to left edge of screen
			skelaton.x = -(skelaton.width >> 1);
			for(int i =0; i<NUM_OF_BEARS; i++)
				if(bear[i].state != 0)
					bear[i].x -= SCREEN_WIDTH;
   
		} // end if

	} // end if   
	else if (skelaton.x < -(skelaton.width >> 1)) // page flip right?
	{
		// bump back regardless
		skelaton.x=-(skelaton.width >> 1);

		// test for page flip
		if (curr_page > 0)
		{ 
			// scroll to next page to left
			curr_page--;
			//reset fire to new position
               if(curr_page==0)
                    Set_Pos_BOB(&fire, 70, 390);
               else if(curr_page==2)
                    Set_Pos_BOB(&fire, 250, 380);
               else if(curr_page==4)
                    Set_Pos_BOB(&fire, 175, 390);
               else if(curr_page==7)
                    Set_Pos_BOB(&fire, 375, 390);
               else if(curr_page==11)
                    Set_Pos_BOB(&fire, 330, 410); 

			// reset character to right edge of screen
			skelaton.x = SCREEN_WIDTH - (skelaton.width >> 1);
			for(int i =0; i<NUM_OF_BEARS; i++)
				if(bear[i].state != 0)
					bear[i].x += SCREEN_WIDTH;
   
		} // end if
	} // end if   

}
else if(paused == true && gameover == false && win == false)
{
	Draw_Text_GDI("PAUSED:  Press SPACE BAR to return, ESCAPE to exit",200,
		(int)(SCREEN_HEIGHT/2), 255, lpddsback);
	if(KEY_DOWN(VK_SPACE))
		paused = false;
}
else if(gameover == true || win == true)
{
	if(KEY_DOWN(VK_RETURN) || KEY_DOWN(VK_ESCAPE))
	{
		PostMessage(main_window_handle, WM_DESTROY,0,0);
	}
}



	// flip the surfaces
	DDraw_Flip();

	// sync to 30 fps
	Wait_Clock(30);


	// return success
	return(1);

} // end Game_Main

void GameOver()
{
	Load_Bitmap_File(&bitmap8bit,"gameover.bmp");
	Create_Bitmap(&gameoverscreen,0,0,640,480);
	Load_Image_Bitmap(&gameoverscreen,&bitmap8bit,0,0,BITMAP_EXTRACT_MODE_ABS);
	Unload_Bitmap_File(&bitmap8bit);

	Set_Palette(bitmap8bit.palette);

	DSound_Stop_All_Sounds();
	
	if(DMusic_Status_MIDI(midi_ids[REGULAR_MUSIC]) == MIDI_PLAYING)
		DMusic_Stop(midi_ids[REGULAR_MUSIC]);
	if(DMusic_Status_MIDI(midi_ids[ATTACK_MUSIC]) == MIDI_PLAYING)
		DMusic_Stop(midi_ids[ATTACK_MUSIC]);

	DSound_Play(sound_ids[SNAKE_DEAD],0, 100,0,0);
	DMusic_Play(midi_ids[GAME_OVER]);

	while(!KEY_DOWN(VK_ESCAPE) && !KEY_DOWN(VK_RETURN))
	{

	// start the timing clock
	Start_Clock();
	
	// clear the drawing surface
	DDraw_Fill_Surface(lpddsback, 0);

	// lock the back buffer
	DDraw_Lock_Back_Surface();

	// draw the background reactor image
	Draw_Bitmap(&gameoverscreen, back_buffer, back_lpitch, 0);

	// unlock the back buffer
	DDraw_Unlock_Back_Surface();
	
	// flip the surfaces
	DDraw_Flip();

	// sync to 30 fps
	Wait_Clock(30);

	}
	PostMessage(main_window_handle, WM_DESTROY,0,0);
}

void GameWin()
{
	Load_Bitmap_File(&bitmap8bit,"gamewin.bmp");
	Create_Bitmap(&gameoverscreen,0,0,640,480);
	Load_Image_Bitmap(&gameoverscreen,&bitmap8bit,0,0,BITMAP_EXTRACT_MODE_ABS);
	Unload_Bitmap_File(&bitmap8bit);

	Set_Palette(bitmap8bit.palette);

	DSound_Stop_All_Sounds();
	
	if(DMusic_Status_MIDI(midi_ids[REGULAR_MUSIC]) == MIDI_PLAYING)
		DMusic_Stop(midi_ids[REGULAR_MUSIC]);
	if(DMusic_Status_MIDI(midi_ids[ATTACK_MUSIC]) == MIDI_PLAYING)
		DMusic_Stop(midi_ids[ATTACK_MUSIC]);

	DMusic_Play(midi_ids[GAME_WIN]);

	for(int i = 0; i < NUM_OF_BEARS; i++)
	{
		if(bear[i].counter_1 == AWARE || bear[i].counter_1 == ATTACK ||
			bear[i].counter_1 == SPOTS)
			spot_counter++;
	}

	while(!KEY_DOWN(VK_ESCAPE) && !KEY_DOWN(VK_RETURN))
	{

	// start the timing clock
	Start_Clock();
	
	// clear the drawing surface
	DDraw_Fill_Surface(lpddsback, 0);

	// lock the back buffer
	DDraw_Lock_Back_Surface();

	// draw the background reactor image
	Draw_Bitmap(&gameoverscreen, back_buffer, back_lpitch, 0);

	

	sprintf(buffer,"NUMBER OF TIMES YOU WERE SPOTTED: %d", spot_counter);
	Draw_Text_GDI(buffer, 25, 440, 255, lpddsback);

	// unlock the back buffer
	DDraw_Unlock_Back_Surface();
	
	// flip the surfaces
	DDraw_Flip();

	// sync to 30 fps
	Wait_Clock(30);

	}
	PostMessage(main_window_handle, WM_DESTROY,0,0);

}

//////////////////////////////////////////////////////////
